@@ -2,6 +2,7 @@
 
 import pickle
 import os
+from sidechainnet.dataloaders.SCNDataset import SCNDataset
 
 import requests
 import tqdm
@@ -100,7 +101,9 @@ def load(casp_version=12,
          optimize_for_cpu_parallelism=False,
          train_eval_downsample=.2,
          filter_by_resolution=False,
-         complete_structures_only=False):
+         complete_structures_only=False,
+         local_scn_path=None,
+         scn_dataset=False):
     #: Okay
     """Load and return the specified SidechainNet dataset as a dictionary or DataLoaders.
 
@@ -176,6 +179,11 @@ def load(casp_version=12,
         complete_structures_only (bool, optional): If True, yield only structures from the
             training set that have no missing residues. Filter not applied to other data
             splits. Default False.
+        local_scn_path (str, optional): The path for a locally saved SidechainNet file.
+            This is especially useful for loading custom SidechainNet datasets.
+        scn_dataset (bool, optional): If True, return a sidechainnet.SCNDataset object
+            for conveniently accessing properties of the data.
+            (See sidechainnet.SCNDataset) for more information.
 
     Returns:
         A Python dictionary that maps data splits ('train', 'test', 'train-eval',
@@ -242,9 +250,12 @@ def load(casp_version=12,
                 ....    prediction = model(sequence, pssm)
                 ....    ...
     """
-    local_path = _get_local_sidechainnet_path(casp_version, thinning, scn_dir)
-    if not local_path:
-        print(f"SidechainNet{(casp_version, thinning)} was not found in {scn_dir}.")
+    if local_scn_path:
+        local_path = local_scn_path
+    else:
+        local_path = _get_local_sidechainnet_path(casp_version, thinning, scn_dir)
+        if not local_path:
+            print(f"SidechainNet{(casp_version, thinning)} was not found in {scn_dir}.")
     if not local_path or force_download:
         # Download SidechainNet if it does not exist locally, or if requested
         local_path = _download_sidechainnet(casp_version, thinning, scn_dir)
@@ -255,8 +266,10 @@ def load(casp_version=12,
         scn_dict = filter_dictionary_by_missing_residues(scn_dict)
 
     # By default, the load function returns a dictionary
-    if not with_pytorch:
+    if not with_pytorch and not scn_dataset:
         return scn_dict
+    elif not with_pytorch and scn_dataset:
+        return SCNDataset(scn_dict)
 
     if with_pytorch == "dataloaders":
         return prepare_dataloaders(
@@ -297,15 +310,16 @@ def filter_dictionary_by_resolution(raw_data, threshold=False):
         "msk": [],
         "crd": [],
         "sec": [],
-        "res": []
+        "res": [],
+        "ums": [],
+        "mod": []
     }
     train = raw_data["train"]
     n_filtered_entries = 0
     total_entires = 0.
-    for seq, ang, crd, msk, evo, _id, res, sec in zip(train['seq'], train['ang'],
-                                                      train['crd'], train['msk'],
-                                                      train['evo'], train['ids'],
-                                                      train['res'], train['sec']):
+    for seq, ang, crd, msk, evo, _id, res, sec, ums, mod in zip(
+            train['seq'], train['ang'], train['crd'], train['msk'], train['evo'],
+            train['ids'], train['res'], train['sec'], train['ums'], train['mod']):
         total_entires += 1
         if not res or res > threshold:
             n_filtered_entries += 1
@@ -319,6 +333,8 @@ def filter_dictionary_by_resolution(raw_data, threshold=False):
             new_data["crd"].append(crd)
             new_data["sec"].append(sec)
             new_data["res"].append(res)
+            new_data["ums"].append(ums)
+            new_data["mod"].append(mod)
     if n_filtered_entries:
         print(f"{n_filtered_entries} ({n_filtered_entries/total_entires:.1%})"
               " training set entries were excluded based on resolution.")
@@ -343,15 +359,16 @@ def filter_dictionary_by_missing_residues(raw_data):
         "msk": [],
         "crd": [],
         "sec": [],
-        "res": []
+        "res": [],
+        "ums": [],
+        "mod": []
     }
     train = raw_data["train"]
     n_filtered_entries = 0
     total_entires = 0.
-    for seq, ang, crd, msk, evo, _id, res, sec in zip(train['seq'], train['ang'],
-                                                      train['crd'], train['msk'],
-                                                      train['evo'], train['ids'],
-                                                      train['res'], train['sec']):
+    for seq, ang, crd, msk, evo, _id, res, sec, ums, mod in zip(
+            train['seq'], train['ang'], train['crd'], train['msk'], train['evo'],
+            train['ids'], train['res'], train['sec'], train['ums'], train['mod']):
         total_entires += 1
         if "-" in msk:
             n_filtered_entries += 1
@@ -365,6 +382,9 @@ def filter_dictionary_by_missing_residues(raw_data):
             new_data["crd"].append(crd)
             new_data["sec"].append(sec)
             new_data["res"].append(res)
+            new_data["ums"].append(ums)
+            new_data["mod"].append(mod)
+
     if n_filtered_entries:
         print(f"{n_filtered_entries} ({n_filtered_entries/total_entires:.1%})"
               " training set entries were excluded based on missing residues.")
